/***********************************************************************/
/* SQL scripts for 2.02 SU1  SQL scripts  STARTS                       */
/***********************************************************************/

/***********************************************************************/
/* 1) CR number: NON   Samia El-Hennawey   NO PEP	This is in SU2	   */  
/* Update to nbresourceparameter table if a line is missing            */
/***********************************************************************/

IF NOT EXISTS (SELECT 1 FROM NBResourceParameter WHERE ParameterID = 471) THEN
	INSERT into nbresourceparameter values(471,3,'NUM_TEMPREMOTE_USERS','Number of temporary remote users',1000,0,0);
END IF;

/***********************************************************************/
/* 2) CR number: Q00637547   Ken Wong  PEP CP20127G023S                */ 
/* Script for correcting mistake in NBomMaps table after installation  */
/***********************************************************************/

IF EXISTS (select 1 from sysobjects where name='NBomMaps') THEN
	UPDATE NBomMaps SET
		_Value = 'NBASDN' where _Group = 'C2T' and _Key = 'APPSERVICEPROFILE'
END IF;



/***********************************************************************/
/* 3) CR number: Q00620076   David Saunders  PEP ?????????             */ 
/* Customized events cause AOS to consume large amounts of CPU         */
/* After 107 upgrade.  Can be applied any time                         */ 
/***********************************************************************/

IF EXISTS (select EventCode from nbEventPreference)THEN
  UPDATE nbEventPreference SET PreferenceEntryID = EventCode
END IF;



/***********************************************************************/
/* 4)CR number: Q00626977   David Saunders							   */
/*			  PEP  CP20127G013S -  PEP CP20127G031S                    */
/*                        PEP  CP20127G041S -  PEP CP20127G045S        */  
/* Script for inserting EN Diagnostics AppId and increasing throttling */ 
/* limit for debug event 54920                                         */
/***********************************************************************/

IF NOT EXISTS (SELECT AppID FROM NBMMApp WHERE AppID=55) THEN
	insert NBMMApp values(55,3,1,'Enterprise Diagnostics',1,'an_main.run',0,0,'MPCX','');
END IF;

IF NOT EXISTS (SELECT AppID FROM NBASDN WHERE AppID=55) THEN
BEGIN
DECLARE @maxnum INTEGER;
	SELECT counter INTO @maxnum from NMCOUNTER where COUNTERID = 32;
	update NMCOUNTER set COUNTER = (@maxnum+1) where COUNTERID = 32;
	insert NBASDN values((@maxnum+1),1,'OUTBOUND55',1,1,3,'MPCX',55,'Enterprise Diagnostics',0,-1,1,'an_main.run',
                        0,'MPCX','',NULL,10,1,5,40,'','','',1,0,0,0,1,'','',2,'',NULL,0,0,NULL,'',0,1,0);
END;
END IF;

IF NOT EXISTS (SELECT EventCode FROM NBEventPreference WHERE EventCode=54920) THEN
	insert NBEventPreference values(54920,NULL,NULL,NULL,NULL,128,NULL,NULL,300,5,54920);
END IF;



/***********************************************************************/
/* 5) CR number: Q00715704-01   Vladislav Belyaev NO PEP               */   
/* Email by phone won't work if email account name exceeds 32          */
/* characters - DATABASE                                               */
/* Note: make sure that Q00715704 is in with this fix                  */
/***********************************************************************/

IF EXISTS (select 1 from syscolumns where tname = 'nmemailaccount' and cname = 'Accountname') then
	alter table nmemailaccount modify Accountname binary(162);
END IF;

IF EXISTS (select 1 from syscolumns where tname = 'nmemailaccount' and cname = 'UserName') then
	alter table nmemailaccount modify UserName binary(322);
END IF;

IF EXISTS (select 1 from syscolumns where tname = 'nmemailaccount' and cname = 'TTSFolder') then
	alter table nmemailaccount modify TTSFolder binary(162);
END IF;


/***********************************************************************/
/* 6) CR number: Q00597040   Samia El-Hennawey   NO PEP                */  
/*  Delay Before C                                                     */
/***********************************************************************/

ALTER TABLE "blue"."NMServerConnection" ALTER  DelayBeforeC SET DEFAULT 0;   	
UPDATE NMServerConnection SET DelayBeforeC=0; 


    
/***********************************************************************/
/* 7) CR number:   Q00628711       Samia El-Hennawey NO PEP            */
/* Remote Users being deleted from system and overwritten after        */
/* 200 have been added                                                 */
/***********************************************************************/
IF EXISTS (select 1 from systrigger where trigger_name='ValSysLimitBeforeUserDelete') THEN
   DROP TRIGGER ValSysLimitBeforeUserDelete;
END IF;

CREATE TRIGGER
ValSysLimitBeforeUserDelete BEFORE DELETE ORDER 3
ON NMMBoxUser
REFERENCING OLD AS deleted
FOR EACH ROW
BEGIN
    declare @Decrement integer;
    SET @Decrement = -1;
    IF(deleted.UserType = 16) THEN
        CALL UpdateResourceCounter (471, @Decrement );
     END IF;
 

    IF (deleted.UserType = 8) THEN
       UPDATE NMCOS SET NMCOS.Counter = NMCOS.Counter + @Decrement WHERE NMCOS.COSId = deleted.COSID;
       CALL UpdateResourceCounters (deleted.COSID, @Decrement);
       CALL UpdateResourceCounter  (401, @Decrement);
    END IF;
END;



IF EXISTS (select 1 from systrigger where trigger_name='ValSysLimitAfterUserUpdate') THEN
   DROP TRIGGER ValSysLimitAfterUserUpdate;
END IF;

CREATE TRIGGER
ValSysLimitAfterUserUpdate AFTER UPDATE OF COSID, UserType ORDER 3
ON NMMBoxUser
REFERENCING OLD AS deleted new AS inserted
FOR EACH ROW
BEGIN
   declare @Increment integer;
   declare @Decrement integer;

   /* Do a dummy increment to lock up both entries at the same time */
   UPDATE NMCOS SET NMCOS.Counter = NMCOS.Counter + 0
      WHERE NMCOS.COSId = inserted.COSID OR NMCOS.COSId = deleted.COSID;

   IF (inserted.UserType = 8) AND (deleted.UserType = 8) THEN
      SET @Increment = 1;
      SET @Decrement = -1;
   ELSEIF (inserted.UserType <> 8) AND (deleted.UserType = 8) THEN
      SET @Increment = 0;
      SET @Decrement = -1;
   ELSEIF (inserted.UserType = 8) AND (deleted.UserType <> 8) THEN
      SET @Increment = 1;
      SET @Decrement = 0;
   ELSE
      SET @Increment = 0;
      SET @Decrement = 0;
   END IF;

   IF (@Increment <> 0) THEN
      UPDATE NMCOS SET NMCOS.Counter = NMCOS.Counter + @Increment WHERE NMCOS.COSId = inserted.COSID;
      CALL UpdateResourceCounters (inserted.COSID, @Increment);
   END IF;

   IF (@Decrement <> 0) THEN
      UPDATE NMCOS SET NMCOS.Counter = NMCOS.Counter + @Decrement WHERE NMCOS.COSId = deleted.COSID;
      CALL UpdateResourceCounters (deleted.COSID,  @Decrement);
   END IF;

   IF ((@Increment + @Decrement) <> 0) THEN
      CALL UpdateResourceCounter  (401, @Increment + @Decrement);
   END IF;

   IF (inserted.UserType = 16) AND (deleted.UserType <> 16) THEN
      SET @Increment = 1;
      CALL UpdateResourceCounter  (471, @Increment );

   ELSEIF (inserted.UserType <> 16) AND (deleted.UserType = 16) THEN
      SET @Decrement = -1;
      CALL UpdateResourceCounter  (471, @Decrement );
   END IF;

END;

IF EXISTS (SELECT 1 FROM nmmboxuser WHERE userType=16) THEN
BEGIN
	declare @TempRemoteUsersCount integer;
	SELECT COUNT(userType) into @TempRemoteUsersCount FROM nmmboxuser WHERE userType=16;
	UPDATE NBResourceParameter SET CurrentValue = @TempRemoteUsersCount WHERE ParameterID = 471;
END;
END IF;



/***********************************************************************/
/*  8) CR number :  Q00641388   Samia  El-Hennawey  NO PEP             */
/* Enable Integrated Networking , Challenge/Response Authentication    */
/* and  Unauthenticated                                                */
/* options must be defaulted to 1 after upgrade from 107               */
/***********************************************************************/

IF EXISTS(select Unauthenticated, ChallengeResponse, UserEnableIntegratedNetwk  from NMGeneralDelivery) THEN
BEGIN
	ALTER TABLE "blue"."NMGeneralDelivery" ALTER  Unauthenticated SET DEFAULT 1; 
	ALTER TABLE "blue"."NMGeneralDelivery" ALTER  ChallengeResponse SET DEFAULT 1; 
	ALTER TABLE "blue"."NMGeneralDelivery" ALTER  UserEnableIntegratedNetwk SET DEFAULT 1; 
	update  NMGeneralDelivery set Unauthenticated =1;
	update  NMGeneralDelivery  set ChallengeResponse=1;
	update  NMGeneralDelivery set UserEnableIntegratedNetwk=1;
END;
END IF;



/***********************************************************************/
/*  9) CR number :  Q00694396  Samia  El-Hennawey NO PEP	    	   */
/*  Can Not Add Holidays After Upg since the nmcounter table has not   */
/*  been updated with the correct number of holidays after upgrade     */
/*  from 1.07 to 2.0.                                                  */
/***********************************************************************/    

IF EXISTS( select *  from nmholidays) THEN
BEGIN
	declare @holidaysnum INTEGER; 
	select count(*) into @holidaysnum  from nmholidays;
	update nmcounter set counter=@holidaysnum where counterid=48;
END;
END IF;



/***********************************************************************/
/* 10) CR number :  Q00726858    Samia El-Hennawey NO PEP              */ 
/* CP 2.5 My CallPilot can't login to e-mail server                    */
/***********************************************************************/
IF NOT EXISTS (select 1 FROM "dbo"."syscolumns" where id in (select id from sysobjects where name='NMEmailServer') and name='SMTPIPAddress' ) THEN
BEGIN	
	ALTER TABLE "blue"."NMEmailServer" ADD SMTPIPAddress     VARCHAR(46);
	ALTER TABLE "blue"."NMEmailServer" ADD SMTPServerPort    INTEGER DEFAULT 25;
	ALTER TABLE "blue"."NMEmailServer" ADD SMTPSSLEnabled    tBoolean DEFAULT 0;
	ALTER TABLE "blue"."NMEmailServer" ADD SSLEnabled        tBoolean DEFAULT 0;
	ALTER TABLE "blue"."NMEmailServer" ADD SMTPFQDN          VARCHAR(511);
	UPDATE NMEmailServer SET SMTPIPAddress = IPAddress;
	UPDATE NMEmailServer SET SMTPFQDN = FQDN;
	UPDATE NMEmailServer SET SMTPServerPort = 25;
	UPDATE NMEmailServer SET SMTPSSLEnabled = 0;
	UPDATE NMEmailServer SET SSLEnabled = 0;
END;
END IF;

/***********************************************************************/
/* 11) CR number :  Q00745111    Vladislav Belyaev   NO PEP            */ 
/* EBP -  password lenght should be 80 characters                      */
/***********************************************************************/
IF EXISTS (select 1 from syscolumns where tname = 'nmemailaccount' and cname = 'Password') then
	ALTER TABLE  blue.NMEmailAccount modify Password binary(162);
END IF;

/***********************************************************************/
/* 12) CR number: Q00781718   Samia El-Hennawey   NO PEP               */  
/* Callpilot 2.02 populates MBX folder name with INBO from Mycallpilot */
/***********************************************************************/
IF EXISTS (select 1 from syscolumns where tname = 'NMEmailAccount' and cname = 'TTSFolder') THEN
BEGIN
ALTER TABLE "blue"."NMEmailAccount" ALTER  TTSFolder SET DEFAULT 0x49004E0042004F0058000000;   	
UPDATE "blue"."NMEmailAccount" SET TTSFolder=0x49004E0042004F0058000000  where TTSFolder=0x49004E0042004F005800; 
END;
END IF;

/***********************************************************************/
/* SQL scripts for 2.02 SU02  SQL scripts  STARTS                       */
/***********************************************************************/

/*************************************************************************/
/* 1) CR number: Q00792783   Ken Wong  PEP None							 */ 
/* Need to increase Maximum Temporary Remote Users in CallPilot to 5,000 */
/*************************************************************************/

IF EXISTS (select 1 from NBResourceParameter where ParameterID=471) THEN
  UPDATE NBResourceParameter SET SystemLimit=5000 where ParameterID=471
END IF;

/***********************************************************************/
/* SQL scripts for 2.02 SU03  SQL scripts  STARTS                       */
/***********************************************************************/

/*************************************************************************/
/* 1)CR number: Q00872237  & Q00834738   Behnaz Ganji					   	 */ 
/* Command Entry Timeout affecting appbuilder applications	             */
/*************************************************************************/
IF EXISTS( select CommandTimeout  from NMCustProf ) THEN
UPDATE NMCustProf set CommandTimeout  = 3500;
END IF;

/****************************************************************************/
/* 2)CR number: Q00516346   Samia El-Hennawey  PEP							*/ 
/* Incorrect value in column ClientNetworkAddress of table NMomAdminJournal */
/****************************************************************************/

IF EXISTS( SELECT 1 FROM syscolumns WHERE tname='NMCustProf' and cname ='LoopbackMbxID') THEN
	UPDATE NMCustProf SET LoopbackMbxID=0x0000000000000000;  
END IF;

IF EXISTS( SELECT 1 FROM syscolumns WHERE tname='NMMBoxUser' and cname ='EntryName') THEN
	UPDATE NMMBoxUser SET userID=0x0000000000000000 where EntryName='Default Loopback mailbox';   
END IF;

/***********************************************************************/
/* 3)CR number: Q00862676              Samia El-Hennawey NO PEP		   */   
/* channels are locked up									           */
/***********************************************************************/

IF EXISTS (select 1 from syscolumns where tname = 'nbasdn' and cname = 'ASI') then
	alter table nbasdn modify ASI varchar(64);
END IF;

IF EXISTS (select 1 from syscolumns where tname = 'nbasdn' and cname = 'AccessDN') then
	alter table nbasdn modify AccessDN varchar(60);
END IF;

IF EXISTS (select 1 from syscolumns where tname = 'nbasdn' and cname = 'Description') then
	alter table nbasdn modify Description varchar(256);
END IF;

IF EXISTS (select 1 from syscolumns where tname = 'nbasdn' and cname = 'MailboxNumber') then
	alter table nbasdn modify MailboxNumber varchar(60);
END IF;

IF EXISTS (select 1 from syscolumns where tname = 'nbasdn' and cname = 'SndrFaxNumber') then
	alter table nbasdn modify SndrFaxNumber varchar(40);
END IF;

IF EXISTS (select 1 from syscolumns where tname = 'nbasdn' and cname = 'ServiceName') then
	alter table nbasdn modify ServiceName varchar(240);
END IF;


/****************************************************************************/
/* 4) CR number: Q00565786, Alexey Marzan							            */ 
/* Incorrect value in column ClientNetworkAddress of table NMomAdminJournal */
/****************************************************************************/
/* When an user changes its COS, update NMCOS counters and CurrentValues in */
/* NBResourceParameter                                                      */
IF EXISTS (select 1 from systrigger where trigger_name='ValSysLimitAfterUserUpdate') THEN
   DROP TRIGGER ValSysLimitAfterUserUpdate;
END IF;
go

CREATE TRIGGER
ValSysLimitAfterUserUpdate AFTER UPDATE OF COSID, UserType ORDER 3
ON NMMBoxUser
REFERENCING OLD AS deleted new AS inserted
FOR EACH ROW
BEGIN
   declare @Increment integer;
   declare @Decrement integer;

   /* Do a dummy increment to lock up both entries at the same time */
   UPDATE NMCOS SET NMCOS.Counter = NMCOS.Counter + 0
      WHERE NMCOS.COSId = inserted.COSID OR NMCOS.COSId = deleted.COSID;

   IF (inserted.UserType = 8) AND (deleted.UserType = 8) THEN
      SET @Increment = 1;
      SET @Decrement = -1;
   ELSEIF (inserted.UserType <> 8) AND (deleted.UserType = 8) THEN
      SET @Increment = 0;
      SET @Decrement = -1;
   ELSEIF (inserted.UserType = 8) AND (deleted.UserType <> 8) THEN
      SET @Increment = 1;
      SET @Decrement = 0;
   ELSE
      SET @Increment = 0;
      SET @Decrement = 0;
   END IF;

  /* START. Q00565786, marzan. Order of IF operations is changed. */
   IF (@Decrement <> 0) THEN
      UPDATE NMCOS SET NMCOS.Counter = NMCOS.Counter + @Decrement WHERE NMCOS.COSId = deleted.COSID;
      CALL UpdateResourceCounters (deleted.COSID,  @Decrement);
   END IF;

   IF (@Increment <> 0) THEN
      UPDATE NMCOS SET NMCOS.Counter = NMCOS.Counter + @Increment WHERE NMCOS.COSId = inserted.COSID;
      CALL UpdateResourceCounters (inserted.COSID, @Increment);
   END IF;
  /* END. Q00565786, marzan. */

   IF ((@Increment + @Decrement) <> 0) THEN
      CALL UpdateResourceCounter  (401, @Increment + @Decrement);
   END IF;

	/* START  Q00628711 : S.E. */
	/* TITLE: Remote Users being deleted from system and overwritten after 200 have been added */

   IF (inserted.UserType = 16) AND (deleted.UserType <> 16) THEN
      SET @Increment = 1;
      CALL UpdateResourceCounter  (471, @Increment );
   ELSEIF (inserted.UserType <> 16) AND (deleted.UserType = 16) THEN
      SET @Decrement = -1;
      CALL UpdateResourceCounter  (471, @Decrement );
   END IF;
   /* END  Q00628711 : S.E. */

END;



/****************************************************************************/
/* 5) CR number: Q00869407   Dmitry Manzhasov      							*/ 
/* User mailbox with User admin right could not view/open other mailbox     */
/****************************************************************************/
IF NOT EXISTS (SELECT 1 FROM "blue"."NMCPMAppObjectMap" WHERE CPMAppID=1 and ObjectClassId=73) THEN
	INSERT INTO "blue"."NMCPMAppObjectMap" (CPMAppId,ObjectClassId) VALUES (1,73);
END IF;

IF NOT EXISTS (SELECT 1 FROM "blue"."NMCPMAppObjectMap" WHERE CPMAppID=2 and ObjectClassId=73) THEN
	INSERT INTO "blue"."NMCPMAppObjectMap" (CPMAppId,ObjectClassId) VALUES (2,73);
END IF;

IF NOT EXISTS (SELECT 1 FROM "blue"."NMCPMAppObjectMap" WHERE CPMAppID=3 and ObjectClassId=73) THEN
	INSERT INTO "blue"."NMCPMAppObjectMap" (CPMAppId,ObjectClassId) VALUES (3,73);
END IF;

/****************************************************************************/
/* 6) CR number: Q00738493   Sergey Semenov      							    */ 
/* Partial Administrator with only Backup/restore privileges cant access   */
/****************************************************************************/
IF NOT EXISTS (select 1 from NMCPMAppObjectMap where CPMAppID=9 and ObjectClassId=100) THEN
   insert into NMCPMAppObjectMap (CPMAppID, OBjectClassID) values (9, 100);
END IF;

IF NOT EXISTS (select 1 from NMCPMAppObjectMap where CPMAppID=10 and ObjectClassId=100) THEN
   insert into NMCPMAppObjectMap (CPMAppID, OBjectClassID) values (10, 100);
END IF;

/***************************************************************/
/*********************  Commit all changes  ********************/
/***************************************************************/

COMMIT;
